Module handler

Module handler 

Structs

HandlerRegistry
Registry of call, run, and custom task handlers. Uses Arc for cheap cloning — handlers are shared across workflow context propagation.

Traits

CallHandler
Handler for call task types that require custom implementations.
CustomTaskHandler
Handler for custom/extension task types.
RunHandler
Handler for run task types that require custom implementations.