HandlerContext

Struct HandlerContext 

pub struct HandlerContext { /* private fields */ }
Read-only snapshot of workflow context variables available to task handlers.

Provides access to $context, $secret, $workflow, and other runtime variables that were previously inaccessible from custom handlers.

Example

use async_trait::async_trait;
use serde_json::Value;
use swf_runtime::{CustomTaskHandler, HandlerContext, WorkflowResult};

struct SmartHandler;

#[async_trait]
impl CustomTaskHandler for SmartHandler {
    fn task_type(&self) -> &str { "smart" }

    async fn handle(
        &self,
        task_name: &str,
        task_type: &str,
        task_config: &Value,
        input: &Value,
        context: &HandlerContext,
    ) -> WorkflowResult<Value> {
        // Access $context to read workflow state
        let preferred = context.context().get("provider").and_then(|v| v.as_str());
        // Access $secret for credentials
        let api_key = context.secret().and_then(|s| s.get("API_KEY")).and_then(|v| v.as_str());
        Ok(input.clone())
    }
}

Implementations

Source

impl HandlerContext

pub fn context(&self) -> &Value

Returns the $context value (workflow instance state set by export.as)

pub fn secret(&self) -> Option<&Value>

Returns the $secret value (all resolved secrets), if a secret manager is configured

pub fn workflow(&self) -> &Value

Returns the $workflow descriptor (workflow metadata)

pub fn authorization(&self) -> Option<&Value>

Returns the $authorization value (set after HTTP authentication), if any