Module status
swf_
runtime
1.0.0-alpha9
Module status
Module Items
Structs
Enums
In crate swf_
runtime
swf_runtime
Module
status
Structs

Status
Phase
Log
A log entry recording a status phase transition with timestamp
Enums

Status
Phase
Represents the execution status phase of a workflow or task