pub struct StatusPhaseLog {
pub timestamp: i64,
pub status: StatusPhase,
}Expand description
A log entry recording a status phase transition with timestamp
Fields
timestamp: i64Unix timestamp in milliseconds
status: StatusPhaseThe status phase
Implementations
Sourceimpl StatusPhaseLog
impl StatusPhaseLog
Sourcepub fn new(status: StatusPhase) -> Self
pub fn new(status: StatusPhase) -> Self
Creates a new status phase log entry with the current timestamp