docs.rs failed to build swf-runtime-1.0.0-alpha10
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
swf-runtime-1.0.0-alpha9
swf_runtime
Execution engine for Serverless Workflow DSL v1.0.0 — parse, validate, and run workflows.
Features
- Task runners — set, wait, raise, emit, switch, for, fork, do, try, listen, call, run, custom
- Expression engine — JQ-based evaluation (jaq) with runtime variable support (
$context,$secret,$workflow,$task,$runtime) - HTTP client — GET/POST/PUT/DELETE/PATCH with headers, query, auth (Basic, Bearer, Digest, OAuth2, OIDC)
- Shell execution — command, args, environment, return formats
- Sub-workflow — run nested workflow definitions with context propagation
- JSON Schema — input/output validation
- Secret manager — pluggable secret resolution (
$secretvariable) - Execution listener — event-driven workflow monitoring
- Custom tasks — extensible via
CustomTaskHandlertrait