Structs
- Handler
Registry - Registry of call, run, and custom task handlers. Uses Arc for cheap cloning — handlers are shared across workflow context propagation.
Traits
- Call
Handler - Handler for call task types that require custom implementations.
- Custom
Task Handler - Handler for custom/extension task types.
- RunHandler
- Handler for run task types that require custom implementations.